package HTTP::Engine::Role::ResponseWriter;
use Moose::Role;

requires qw(finalize);

1;

